@@ -2,30 +2,20 @@
 #' 
 #' @import XML RCurl RJSONIO plyr
 #' @param id the taxon identifier code 
-#' @param format return in json or xml format (defaults to json)
 #' @param key Your Tropicos API key; loads from .Rprofile.
 #' @param verbose Verbose or not
 #' @return List or dataframe.
 #' @export
 #' @examples \dontrun{
 #' tp_synonyms(id = 25509881)
-#' tp_synonyms(id = 25509881, output = 'raw')
 #' }
-tp_synonyms <- function(id, format = 'json', key = NULL, verbose=TRUE)
+tp_synonyms <- function(id, key = NULL, verbose=TRUE)
 {
   url = 'http://services.tropicos.org/Name/'
 	key <- getkey(key, "tropicosApiKey")
-  if (format == 'json') {
-    urlget <- paste(url, id, '/Synonyms?apikey=', key, '&format=json', sep="")
-    mssg(verbose, urlget)
-    searchresults <- RJSONIO::fromJSON(urlget)
-  } 
-  else {
-    urlget <- paste(url, id, '/Synonyms?apikey=', key, '&format=xml', sep="")
-    mssg(verbose, urlget)
-    xmlout <- getURL(urlget)
-    searchresults <- xmlToList(xmlTreeParse(xmlout))
-  }
+  urlget <- paste(url, id, '/Synonyms?apikey=', key, '&format=json', sep="")
+  mssg(verbose, urlget)
+  searchresults <- RJSONIO::fromJSON(urlget)
   
   if(names(searchresults[[1]])[[1]] == "Error"){
     nonedf <- data.frame(NameId="no syns found",ScientificName="no syns found",ScientificNameWithAuthors="no syns found",Family="no syns found")
@@ -34,9 +24,10 @@ tp_synonyms <- function(id, format = 'json', key = NULL, verbose=TRUE)
   {  
     dat <- lapply(searchresults, function(x) lapply(x, data.frame))
     accepted <- dat[[1]]$AcceptedName
-#     synonyms <- do.call(rbind.fill, lapply(dat, "[[", "SynonymName"))[,c('NameId','ScientificName','Family')]
     df <- do.call(rbind.fill, lapply(dat, "[[", "SynonymName"))
     synonyms <- df[!duplicated.data.frame(df), ]
+    names(accepted) <- tolower(names(accepted))
+    names(synonyms) <- tolower(names(synonyms))
     list(accepted=accepted, synonyms=synonyms)
   }
 }
\ No newline at end of file
